==> haskell-trifecta-2-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: trifecta
version: 2
id: trifecta-2-EsyHT79jIaq6dQK8MD9ONz
key: trifecta-2-EsyHT79jIaq6dQK8MD9ONz
license: BSD-3-Clause
copyright: Copyright (C) 2010-2017 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/trifecta/
synopsis: A modern parser combinator library with convenient diagnostics
description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics
category: Text, Parsing, Diagnostics, Pretty Printer, Logging
abi: 540663847c6cc8801709ff0be5ac3f71
exposed: True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Tutorial Text.Trifecta.Util.Array
    Text.Trifecta.Util.IntervalMap Text.Trifecta.Util.It
hidden-modules: Text.Trifecta.Instances
                Text.Trifecta.Util.Combinators
import-dirs: /usr/lib/ghc-8.6.5/site-local/trifecta-2
library-dirs: /usr/lib/ghc-8.6.5/site-local/trifecta-2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/trifecta-2
hs-libraries: HStrifecta-2-EsyHT79jIaq6dQK8MD9ONz
depends:
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    ansi-wl-pprint-0.6.8.2-IorYGC2IHKLB6bH0iJmQIJ array-0.5.3.0
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    charset-0.3.7.1-IScnJFtw5PtlN6mv65WbN
    comonad-5.0.4-8UKAvbVXEvJ8FD0FgJJhEO containers-0.6.0.1
    deepseq-1.4.4.0 fingertree-0.1.4.2-1pfQ89nAa7tK8TACGnhP3j
    ghc-prim-0.5.3 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    lens-4.17-4Ddy4vxZdXoFxB1RvbUywU mtl-2.2.2
    parsers-0.12.9-DF4eEzdzgqlCwwz7osmX6P
    profunctors-5.3-LjJMPD69dgQLSXhG4SlkOm
    reducers-3.12.3-B9ezLinDVYT4ZMng1QVSi7 transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html: /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-trifecta-2-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-trifecta.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: trifecta
version: 2
id: trifecta-2-KkqEUznNnBlFyMABlW7HyP
key: trifecta-2-KkqEUznNnBlFyMABlW7HyP
license: BSD-3-Clause
copyright: Copyright (C) 2010-2017 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: experimental
homepage: http://github.com/ekmett/trifecta/
synopsis: A modern parser combinator library with convenient diagnostics
description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics
category: Text, Parsing, Diagnostics, Pretty Printer, Logging
abi: 680b392f2c45054e8c1f005dd4eb4be3
exposed: True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Tutorial Text.Trifecta.Util.Array
    Text.Trifecta.Util.IntervalMap Text.Trifecta.Util.It
hidden-modules: Text.Trifecta.Instances
                Text.Trifecta.Util.Combinators
import-dirs: /usr/lib/ghc-8.6.5/site-local/trifecta-2
library-dirs: /usr/lib/ghc-8.6.5/site-local/trifecta-2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/trifecta-2
hs-libraries: HStrifecta-2-KkqEUznNnBlFyMABlW7HyP
depends:
    ansi-terminal-0.8.2-8WQDEUM7Kz3DSmwgHomKFP
    ansi-wl-pprint-0.6.8.2-IorYGC2IHKLB6bH0iJmQIJ array-0.5.3.0
    base-4.12.0.0 blaze-builder-0.4.1.0-KrFxFv3kgua3BTNMsMBadC
    blaze-html-0.9.1.1-A8LR7w4yS96GtRVO7i7OSl
    blaze-markup-0.8.2.2-IwLwNWRUxfsEuYbkQ0Gv5Q bytestring-0.10.8.2
    charset-0.3.7.1-IScnJFtw5PtlN6mv65WbN
    comonad-5.0.5-4jZMLPK948W6C4yBvDor7f containers-0.6.0.1
    deepseq-1.4.4.0 fingertree-0.1.4.2-1pfQ89nAa7tK8TACGnhP3j
    ghc-prim-0.5.3 hashable-1.2.7.0-KHvCgUH7dIl7mI8fl4akIo
    lens-4.17-4rCDtg2DCdcDxZQ0b6ZtZB mtl-2.2.2
    parsers-0.12.9-3MewpnVM0necEe3Glbx5M
    profunctors-5.3-8X2CFHcNNNSKTydsYoPQRb
    reducers-3.12.3-KVmg3LbjxaG8oFcQdwyjSj transformers-0.5.6.2
    unordered-containers-0.2.10.0-5bnYBnE7Vkj9Kd62fWith8
    utf8-string-1.0.1.1-Geq8jdOv4Q3LkcQoEOWDVv
haddock-interfaces: /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html: /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
